
<img src="/img/pyapep_logo04.png" width="20%" height="20%">


# pyAPEP
This is for developing python-based Adsorption Process Evaluation Package (pyapep), solely developed by Dr. Seongbin Ga.

- [01 - Installation](https://github.com/sebyga/pyAPEP_v0_0_5#Installation)
- [02 - Modules](https://github.com/sebyga/pyAPEP_v0_0_5#Modules)


# Installation
You can install this package by using pip.
``` r
pip install pyapep
```

``` r
import pyapep.simsep as papse
c1 = papse.column()
```

Super- and sub- script: x<sup>2</sup> and x<sub>2</sub>

# Modules
There are several modules related to the adsorption processes:
- [1) simsep](https://github.com/sebyga/pyAPEP_v0_0_5#simsep-Module-for-Adsorption-Separation-Processes)
- [2) simsto](https://github.com/sebyga/pyAPEP_v0_0_5#simsto-Module-for-Adsorption-Storage-Processes)
- [3) simide](https://github.com/sebyga/pyAPEP_v0_0_5#simide-Module-Ideal-Adsorption-Processes)

# simsep Module for Adsorption Separation Processes

Edit the equation:
$$ x = \frac{1}{2} \times m c^{2}$$

# simsto Module for Adsorption Storage Processes

# simide Module Ideal Adsorption Processes


# Original Image:

![icon_pyapep](/img/pyapep_logo04.png)
